<?php
/**
 * Class to register panels and sections for customize options.
 *
 * Class MagazineX_Customizer_Register_Section_Panel
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to register panels and sections for customize options.
 *
 * Class MagazineX_Customizer_Register_Section_Panel
 */
class MagazineX_Customizer_Register_Section_Panel extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			/**
			 * Panels.
			 */
			array(
				'name'     => 'magazinex_global_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Global', 'magazinex' ),
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_header_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Header', 'magazinex' ),
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_content_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Content', 'magazinex' ),
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_footer_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Footer', 'magazinex' ),
				'priority' => 40,
			),

			/**
			 * Global.
			 */
			array(
				'name'     => 'magazinex_global_colors_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Colors', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_sidebar_layout_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Sidebar Layout', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'section'  => 'magazinex_layout_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_primary_colors_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Primary Colors', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'section'  => 'magazinex_global_colors_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_layout_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Layout', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_secondary_colors_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Secondary Colors', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'section'  => 'magazinex_global_colors_section',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_headings_color_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Headings', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'section'  => 'magazinex_global_colors_section',
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_link_color_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Link', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'section'  => 'magazinex_global_colors_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_categories_color_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Catagories', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'section'  => 'magazinex_global_colors_section',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_bg_color_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Background', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'section'  => 'magazinex_global_colors_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_background_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Background', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'priority' => 30,
			),

			/**
			 * Header.
			 */
			array(
				'name'     => 'magazinex_header_bar_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Header Bar', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 10,
			),

			array(
				'name'     => 'title_tagline',
				'type'     => 'section',
				'title'    => esc_html__( 'Site Identity', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_primary_header_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Primary Header', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_primary_menu_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Primary Menu', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_page_header_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Page Header', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_drawer_menu_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Drawer Menu', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_header_actions_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Header Actions', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_search_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Search', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_news_ticker_section',
				'type'     => 'section',
				'title'    => esc_html__( 'News Ticker', 'magazinex' ),
				'panel'    => 'magazinex_header_panel',
				'priority' => 70,
			),

			/**
			 * Content.
			 */
			array(
				'name'     => 'magazinex_blog_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Blog', 'magazinex' ),
				'panel'    => 'magazinex_content_panel',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_single_post_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Single Post', 'magazinex' ),
				'panel'    => 'magazinex_content_panel',
				'priority' => 20,
			),

			/**
			 * Footer.
			 */
			array(
				'name'     => 'magazinex_footer_column_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Footer Column', 'magazinex' ),
				'panel'    => 'magazinex_footer_panel',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_footer_bar_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Footer Bar', 'magazinex' ),
				'panel'    => 'magazinex_footer_panel',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_scroll_to_top',
				'type'     => 'section',
				'title'    => esc_html__( 'Scroll to Top', 'magazinex' ),
				'panel'    => 'magazinex_footer_panel',
				'priority' => 30,
			),

			array(
				'name'             => 'magazinex_panel_separator',
				'type'             => 'section',
				'priority'         => 75,
				'section_callback' => 'MagazineX_WP_Customize_Separator',
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customizer_Register_Section_Panel();
