<?php
/**
 * Class to include footer column customize options.
 *
 * Class MagazineX_Customize_Footer_Column_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include footer column customize options.
 *
 * Class MagazineX_Customize_Footer_Column_Options
 */
class MagazineX_Customize_Footer_Column_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(
			array(
				'name'     => 'magazinex_footer_column_layout_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Layout', 'magazinex' ),
				'section'  => 'magazinex_footer_column_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_footer_column_layout',
				'default'  => 'mzx-grid-cols--3',
				'type'     => 'control',
				'control'  => 'magazinex-radio-image',
				'section'  => 'magazinex_footer_column_section',
				'choices'  => array(
					'mzx-grid-cols--1' => array(
						'label' => 'One Column',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/column-1.png',
					),
					'mzx-grid-cols--2' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/column-2.png',
					),
					'mzx-grid-cols--3' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/column-3.png',
					),
				),
				'priority' => 20,
			),

			array(
				'name'          => 'magazinex_footer_block_info',
				'type'          => 'control',
				'control'       => 'magazinex-navigate',
				'section'       => 'magazinex_footer_column_section',
				'navigate_info' => array(
					'target_container' => 'section',
					'target_id'        => 'sidebar-widgets-mzx-footer-col--1',
					'target_label'     => esc_html__( 'Footer Column', 'magazinex' ),
				),
				'priority'      => 30,
			),

			array(
				'name'     => 'magazinex_footer_column_colors_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Colors', 'magazinex' ),
				'section'  => 'magazinex_footer_column_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_footer_column_background_group',
				'label'    => esc_html__( 'Background', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_footer_column_background_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_footer_column_background_group',
				'section'  => 'magazinex_footer_column_section',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_footer_column_heading_color',
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-color',
				'label'    => esc_html__( 'Heading Color', 'magazinex' ),
				'section'  => 'magazinex_footer_column_section',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_footer_column_text_color',
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-color',
				'label'    => esc_html__( 'Text Color', 'magazinex' ),
				'section'  => 'magazinex_footer_column_section',
				'priority' => 70,
			),

			array(
				'name'     => 'magazinex_footer_column_link_color',
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-color',
				'label'    => esc_html__( 'Link Color', 'magazinex' ),
				'section'  => 'magazinex_footer_column_section',
				'priority' => 80,
			),

		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Footer_Column_Options();
