<?php
/**
 * Class to include sidebar layout customize options.
 *
 * Class MagazineX_Customize_Sidebar_Layout_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include sidebar layout customize options.
 *
 * Class MagazineX_Customize_Sidebar_Layout_Options
 */
class MagazineX_Customize_Sidebar_Layout_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(
			array(
				'name'     => 'magazinex_default_sidebar_layout_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Default', 'magazinex' ),
				'section'  => 'magazinex_sidebar_layout_section',
				'priority' => 10,
			),

			array(
				'name'      => 'magazinex_default_sidebar_layout',
				'default'   => 'right',
				'type'      => 'control',
				'control'   => 'magazinex-radio-image',
				'section'   => 'magazinex_sidebar_layout_section',
				'image_col' => 3,
				'choices'   => array(
					'right'      => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/right-sidebar.png',
					),
					'no-sidebar' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/centered.png',
					),
				),
				'priority'  => 20,
			),

			array(
				'name'     => 'magazinex_archive_sidebar_layout_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Archive', 'magazinex' ),
				'section'  => 'magazinex_sidebar_layout_section',
				'priority' => 30,
			),

			array(
				'name'      => 'magazinex_archive_sidebar_layout',
				'default'   => 'right',
				'type'      => 'control',
				'control'   => 'magazinex-radio-image',
				'section'   => 'magazinex_sidebar_layout_section',
				'image_col' => 3,
				'choices'   => array(
					'right'      => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/right-sidebar.png',
					),
					'no-sidebar' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/centered.png',
					),
				),
				'priority'  => 40,
			),

			array(
				'name'     => 'magazinex_page_sidebar_layout_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Page', 'magazinex' ),
				'section'  => 'magazinex_sidebar_layout_section',
				'priority' => 50,
			),

			array(
				'name'      => 'magazinex_page_sidebar_layout',
				'default'   => 'right',
				'type'      => 'control',
				'control'   => 'magazinex-radio-image',
				'section'   => 'magazinex_sidebar_layout_section',
				'image_col' => 3,
				'choices'   => array(
					'right'      => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/right-sidebar.png',
					),
					'no-sidebar' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/centered.png',
					),
				),
				'priority'  => 60,
			),

			array(
				'name'     => 'magazinex_single_post_sidebar_layout_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Single Post', 'magazinex' ),
				'section'  => 'magazinex_sidebar_layout_section',
				'priority' => 70,
			),

			array(
				'name'      => 'magazinex_single_post_sidebar_layout',
				'default'   => 'right',
				'type'      => 'control',
				'control'   => 'magazinex-radio-image',
				'section'   => 'magazinex_sidebar_layout_section',
				'image_col' => 3,
				'choices'   => array(
					'right'      => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/right-sidebar.png',
					),
					'no-sidebar' => array(
						'label' => '',
						'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/centered.png',
					),
				),
				'priority'  => 80,
			),

		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Sidebar_Layout_Options();
