<?php
/**
 * Class to include primary menu customize options.
 *
 * Class MagazineX_Customize_Primary_Menu_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include primary menu customize options.
 *
 * Class MagazineX_Customize_Primary_Menu_Options
 */
class MagazineX_Customize_Primary_Menu_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_primary_menu_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Primary Menu', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_primary_menu_text_colors_group',
				'label'    => esc_html__( 'Colors', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_primary_menu_text_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#111111',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_primary_menu_text_colors_group',
				'tab'      => esc_html__( 'Normal', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_primary_menu_text_hover_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#BA81FF',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_primary_menu_text_colors_group',
				'tab'      => esc_html__( 'Hover', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_primary_menu_text_active_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#BA81FF',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_primary_menu_text_colors_group',
				'tab'      => esc_html__( 'Active', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_sub_menu_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Sub Menu', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_sub_menu_text_colors_group',
				'label'    => esc_html__( 'Colors', 'magazinex' ),
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_sub_menu_text_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#111111',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_sub_menu_text_colors_group',
				'tab'      => esc_html__( 'Normal', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 70,
			),

			array(
				'name'     => 'magazinex_sub_menu_text_hover_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#BA81FF',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_sub_menu_text_colors_group',
				'tab'      => esc_html__( 'Hover', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 80,
			),

			array(
				'name'     => 'magazinex_sub_menu_text_active_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#BA81FF',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_sub_menu_text_colors_group',
				'tab'      => esc_html__( 'Active', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 80,
			),

			array(
				'name'     => 'magazinex_header_actions_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Header Action', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 90,
			),

			array(
				'name'     => 'magazinex_enable_header_action',
				'default'  => 1,
				'type'     => 'control',
				'control'  => 'magazinex-toggle',
				'label'    => esc_html__( 'Enable', 'magazinex' ),
				'section'  => 'magazinex_primary_menu_section',
				'priority' => 100,
			),

			array(
				'name'          => 'magazinex_header_actions_block_info',
				'type'          => 'control',
				'control'       => 'magazinex-navigate',
				'section'       => 'magazinex_primary_menu_section',
				'navigate_info' => array(
					'target_container' => 'section',
					'target_id'        => 'sidebar-widgets-mzx-header-action-sidebar',
					'target_label'     => esc_html__( 'Header Action', 'magazinex' ),
				),
				'dependency'    => array(
					'magazinex_enable_header_action',
					'==',
					true,
				),
				'priority'      => 110,
			),

			array(
				'name'       => 'magazinex_search_heading',
				'type'       => 'control',
				'control'    => 'magazinex-title',
				'label'      => esc_html__( 'Search', 'magazinex' ),
				'section'    => 'magazinex_primary_menu_section',
				'dependency' => array(
					'magazinex_enable_header_action',
					'==',
					true,
				),
				'priority'   => 120,
			),

			array(
				'name'       => 'magazinex_enable_search',
				'default'    => 1,
				'type'       => 'control',
				'control'    => 'magazinex-toggle',
				'label'      => esc_html__( 'Enable', 'magazinex' ),
				'section'    => 'magazinex_primary_menu_section',
				'dependency' => array(
					'magazinex_enable_header_action',
					'==',
					true,
				),
				'priority'   => 130,
			),

		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Primary_Menu_Options();
