<?php
/**
 * Hooks for the content area of the site.
 *
 * @package MagazineX
 * @since   1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'magazinex_excerpt_more' ) ) {

	/**
	 * Remove [...] from excerpts.
	 *
	 * @return void
	 */
	function magazinex_excerpt_more() {
		return; // phpcs:ignore Squiz.PHP.NonExecutableCode.ReturnNotRequired
	}
	add_filter( 'excerpt_more', 'magazinex_excerpt_more' );
}

if ( ! function_exists( 'magazinex_content_loop' ) ) {

	/**
	 * Main content loop.
	 *
	 * @return void
	 */
	function magazinex_content_loop() {

		if ( have_posts() ) :
			?>

			<div class="mzx-posts mzx-grid-col--2 mzx-highlight-post">

				<?php
				while ( have_posts() ) :
					the_post();
						get_template_part( 'template-parts/content/content', '' );
				endwhile;
				?>
			</div>
			<?php

			if ( 'default' === get_theme_mod( 'magazinex_pagination_style', 'default' ) ) :
				get_template_part( 'template-parts/navigation' );
			endif;
			if ( 'numbered' === get_theme_mod( 'magazinex_pagination_style', 'default' ) ) :
				magazinex_numbered_pagination();
			endif;
		else :

			get_template_part( 'template-parts/content/content', 'none' );
		endif;
	}
	add_action( 'magazinex_content', 'magazinex_content_loop' );
	add_action( 'magazinex_content_search', 'magazinex_content_loop' );
	add_action( 'magazinex_content_archive', 'magazinex_content_loop' );
}

if ( ! function_exists( 'magazinex_single_content_loop' ) ) {

	/**
	 * Single content loop.
	 *
	 * @return void
	 */
	function magazinex_single_content_loop() {

		if ( have_posts() ) :
			?>

			<?php
			while ( have_posts() ) :
				the_post();

				get_template_part( 'template-parts/content/content', 'single' );

				magazinex_post_navigation();

				magazinex_related_posts();

				magazinex_comments();
			endwhile; // End of the loop.
		else :

			get_template_part( 'template-parts/content/content', 'none' );
		endif;
	}
	add_action( 'magazinex_content_single', 'magazinex_single_content_loop' );
}

if ( ! function_exists( 'magazinex_related_posts' ) ) :

	/**
	 * Display the related posts if it is enabled via Customize Option.
	 */
	function magazinex_related_posts() {

		// Bail out if related posts is disabled.
		$is_related_posts_enabled = get_theme_mod( 'magazinex_enable_related_posts', 1 );

		if ( ! $is_related_posts_enabled ) {
			return;
		}

		// Related posts query.
		global $post;

		// Define shared post arguments.
		$args = array(
			'no_found_rows'          => true,
			'update_post_meta_cache' => false,
			'update_post_term_cache' => false,
			'ignore_sticky_posts'    => true,
			'orderby'                => 'rand',
			'post__not_in'           => array( $post->ID ),
			'posts_per_page'         => 3,
			'category__in'           => wp_get_post_categories( $post->ID, array( 'fields' => 'ids' ) ),
		);

		$related_posts_query  = new WP_Query( $args );
		$enable_related_posts = get_theme_mod( 'magazinex_related_post', 0 );

		if ( $related_posts_query->have_posts() ) :
			?>

			<div class="mzx-related-posts">

				<h2 class="mzx-related-posts-header">
					<?php esc_html_e( 'Related Articles', 'magazinex' ); ?>
				</h2>

				<div class="mzx-posts mzx-grid-col--3">
					<?php
					while ( $related_posts_query->have_posts() ) :

						$related_posts_query->the_post();

						get_template_part( 'template-parts/related-post/related-post' );

						wp_reset_postdata();
					endwhile;
					?>
				</div>

			</div>
			<?php
		endif;
	}
endif;
